@@ -21,35 +21,35 @@ Test <- setClass(Class = "Test",
 setMethod("initialize", signature(.Object = "Test"),
           function(.Object, mo, item_answers_in, item_options,
                    quadpts_in, theta_range_in, dots){
-              mo@exploratory <- FALSE
+              mo@Options$exploratory <- FALSE
               .Object@itemnames <- colnames(mo@Data$data)
               mo@Data$mins <- rep(0L, length(mo@Data$min))
               .Object@mo <- mo
-              .Object@item_class <- sapply(mo@pars, class)
+              .Object@item_class <- sapply(mo@ParObjects$pars, class)
               if(is.null(item_answers_in))
                   item_answers_in <- as.character(rep(NA, length(.Object@itemnames)))
               
               .Object@item_answers <- as.list(item_answers_in)
               .Object@item_options <- item_options
               .Object@length <- length(.Object@item_answers)
-              .Object@nfact <- mo@nfact
+              .Object@nfact <- mo@Model$nfact
               if(is.null(quadpts_in)) 
-                  .Object@quadpts <- switch(as.character(mo@nfact), 
+                  .Object@quadpts <- switch(as.character(.Object@nfact), 
                                      '1'=61, '2'=31, '3'=15, '4'=9, '5'=7, 3)
               else .Object@quadpts <- quadpts_in
               if(is.null(theta_range_in)) .Object@theta_range <- c(-6, 6)
               else .Object@theta_range <- theta_range_in
-              gp <- mirt:::ExtractGroupPars(mo@pars[[.Object@length + 1L]])
-              if(mo@nfact == 1L){
+              gp <- mirt:::ExtractGroupPars(mo@ParObjects$pars[[.Object@length + 1L]])
+              if(.Object@nfact == 1L){
                   .Object@ThetaGrid <- mirt:::thetaComb(seq(.Object@theta_range[1L],
                                                             .Object@theta_range[2L], 
                                                             length.out=.Object@quadpts),
-                                                        mo@nfact)
+                                                        .Object@nfact)
                   .Object@density <- mirt:::mirt_dmvnorm(.Object@ThetaGrid, mean=gp$gmeans, 
                                                   sigma=gp$gcov)
               }
               .Object@gp <- gp
-              tmp <- mo@itemloc
+              tmp <- mo@Model$itemloc
               .Object@itemloc2 <- as.integer(tmp[-length(tmp)])
               tmp <- list(rotate = 'none', theta_lim = c(-6,6), mean = gp$gmean,
                           cov=gp$gcov, MI = 0, QMC=FALSE, custom_den=NULL)
